@@ -1,7 +1,9 @@
+from .删除记录 import 删除记录
 from .增加_单条记录 import 增加_单条记录
 from .执行SQL语句 import 执行SQL语句
 from .数据库连接_是否活跃 import 数据库连接_是否活跃
 from .断开数据库连接 import 断开数据库连接
+from .更新_JSON字段 import 更新_JSON字段
 from .更新_SQL语句条件 import 更新_SQL语句条件
 from .更新_指定字段空值填充 import 更新_指定字段空值填充
 from .更新_清空字段数据 import 更新_清空字段数据
